%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% FIGURE GENERATION FOR SPM THESIS (2003), ChLi
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fprintf('\n **** SPM: Thesis 2003, ChLi **** ')
clear, cd F: 

% Variables
DO_NOT_CLEAR = 1; c0 = 2.99792e8;
global MYLINEWIDTH MYSUBLINEWIDTH ...
	MYMARKER MYMARKERSIZE MYSUBMARKERSIZE... 
    LINECOLOR MYLINESTYLE...
	MYFONTSIZE MYSUBFONTSIZE...
	CURFIGNO...
	MYXLABELSHIFT MYYLABELSHIFT...
    OUTPUTFIGDIR
OutPutFigDir = [OUTPUTFIGDIR '../CorelDrawDocs/Thesis/ChLi/Figure/'];
	
% Defaults
FigParam.XShift = MYXLABELSHIFT;
FigParam.YShift = MYYLABELSHIFT;
FigParam.LineWidth = MYLINEWIDTH;
FigParam.FontSize = MYFONTSIZE;
FigParam.Color = LINECOLOR;
FigParam.MarkerSize = MYMARKERSIZE;

% Sections:
Noise = 1;
DCLinearity =  0;
ModFreqLimit = 0;
ModAmpdLimit = 0;
LiWaveTest =   0;
UncerCompar =  0;
MonoScan =     0;
ThickerLiquidUncertainty = 0;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Noise Waveform & Spectrum
%
% From time scan on 2002.10.24.
% I believe 'NoiseScanp' means at the THz peak.
% Use the first 8192 points (nominally sampled at 5 ms) - 
%  this gives T = 41 secs, fmin = 0.024 Hz, fmax = 100 Hz.
% Waveforms - plot waveform 'tr01' and a noise scan of approx
%  fluctuation by using 'NoiseScan'. HOWEVER, 'tr01' must be
%  scaled to fit the noise level.
%  Since the waveform dd = 20 micron (not 1.5e6 as in the txt
%  file), the THz time vector must be scaled by 1.333e-11. 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if Noise
	expfile='F:\Data\2002_10_24_DTDS_Noise\SPM_GenericMultiPlot_Noise.txt';
    SPM_GenericMultiPlot
    % DATA WAVEFORM
    ScaledWave = Wave{3}./max(Wave{3}); %Scale the waveform
    ScaleNoise = Wave{2}(1:201)./Wave{2}(find(Wave{3}==max(Wave{3}))); %Scale the noise
    FigData = {[4e1/3*Time{3}',ScaledWave],...
            [4e1/3*Time{2}(1:201)',ScaleNoise]};
    % FIGURE WAVEFORM
	CURFIGNO = CURFIGNO + 1;
	FigParam.FigNo = CURFIGNO;
	FigParam.Name = 'NoiseWaveform';
	FigParam.Style = {'-','-'};
	FigParam.Marker = {'o','none'};
	FigParam.XLim = [0,13.34]; FigParam.YLim = [-0.6,1.2];
    FigParam.Color{2} = [1,0,0];
    Fig.Param.LegPos = 0;
	fnGenericDrawFigure(FigData,FigParam)
	%% PRINT
	%%print('-depsc2',[OutPutFigDir 'NoiseWaveform'])
    %% Copy --> Corel
    % TIDY
    FigParam.Color = LINECOLOR;
	% DATA SPECTRUM
    FreqAbs{1}(1) = 0.01; %Replace '0' manually.
    Fit = 1./FreqAbs{1};
	FigData = {[FreqAbs{1}(NCutAbs{1}),Abs{1}(NCutAbs{1})./Abs{1}(max(find(FreqAbs{1}<=1.0)))],...
        [FreqAbs{1},Fit]};
	% FIGURE SPECTRUM   
	CURFIGNO = CURFIGNO + 1;
	FigParam.FigNo = CURFIGNO;
	FigParam.Name = 'NoiseSpectrum';
	FigParam.Style = {'none','-'};
	FigParam.Marker = {'o','none'};
	FigParam.XLim = [0.01,50]; FigParam.YLim = [1e-2,1e2];
    figure(CURFIGNO), clf
    for cK = 1:2
        PloNo{cK}=loglog(FigData{cK}(:,1),FigData{cK}(:,2));
        set(gca,'FontSize',FigParam.FontSize,...
            'XLim',FigParam.XLim,...
            'YLim',FigParam.YLim)
        set(PloNo{cK},'Color',FigParam.Color{cK},...
            'LineStyle',FigParam.Style{cK},...
            'Marker',FigParam.Marker{cK},...
            'LineWidth',FigParam.LineWidth,...
            'MarkerSize',FigParam.MarkerSize)
        hold on
    end
    XNo = xlabel('XX');
    set(XNo,'Units','points')
    set(XNo,'Position',(get(XNo,'Position')+[0 FigParam.XShift 0]))
    set(XNo,'Units','normalized')
    YNo = ylabel('YY');
    set(YNo,'Units','points')
    set(YNo,'Position',(get(YNo,'Position')+[FigParam.YShift 0 0]))
    set(YNo,'Units','normalized')
    RndPreLeg = ((1:length(FigData))+64)';
    RndLeg = char(RndPreLeg*ones(1,10));
    LegNo{CURFIGNO} = legend(RndLeg);
    legend boxoff
    set(CURFIGNO,'Color','none')
	%% PRINT
	%%print('-depsc2',[OutPutFigDir 'NoiseSpectrum'])
    %% Copy --> Corel
end	


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Speaker DC Linearity
%
% Originally from 'Presentation_2002_LiqDTDS.m'.
% DC Linearity ('LiqDTDS_DCLinearity')
%  (Manual measurements by Regina Shvartsham on
%  2002.07.26.)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if DCLinearity
    % DATA
    load('F:Data/2002_07_26_Regina/Speaker_Displacement_v_Voltage.mat')
	LinearApprox = 0.36*SigGen_DCVolts;
    FigData = {[Speaker_DCVolts_1,Displacement_mm_1],...
		[Speaker_DCVolts_2,Displacement_mm_2],...
		[SigGen_DCVolts,LinearApprox]};
    % FIGURE
	CURFIGNO = CURFIGNO + 1;
	FigParam.FigNo = CURFIGNO;
	FigParam.Name = 'DCLinearity';
	FigParam.Style = {'none','none','-'};
	FigParam.Marker = {'o','+','none'};
	FigParam.XLim = [-4,4]; FigParam.YLim = [-1.5,1.5];
    FigParam.LegPos = 2; %Up LHS
	fnGenericDrawFigure(FigData,FigParam)
	text(1.4,0.2,'EQUATION1','FontSize',FigParam.FontSize)
	% PRINT
	%print('-depsc2',[OutPutFigDir 'DCLinearity'])
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Modulation frequency limitations
%
% Originally from 'Data_2002_07_22_RangePlots'
% with the switch set to 'Comparison Plots'.
%  Using data from 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if ModFreqLimit
	% THz freqs of interest
	F1 = 0.4; F2 = 0.8; 
	% 1V AC
	for cK = 1:3
		load(['F:/Data/2002_07_22/SPM_GenericMultiPlot',...
                num2str(cK+1) '_Ratio'])
		OneRatF1(cK) = RegRat(max(find(RegFr<=F1)));
		OneRatF2(cK) = RegRat(max(find(RegFr<=F2)));
	end
	% 2V AC
	for cK = 1:11
		load(['F:/Data/2002_07_22/SPM_GenericMultiPlot',...
                num2str(cK+4) '_Ratio'])
		TwoRatF1(cK) = RegRat(max(find(RegFr<=F1)));
		TwoRatF2(cK) = RegRat(max(find(RegFr<=F2)));
	end
	% DATA
	OneModFreq = [0.1 0.5 1];
	TwoModFreq = [0.5 1 2 4 6 8 12 16 20 24 30];
    FigData = {[OneModFreq',OneRatF1'],...
            [OneModFreq',OneRatF2'],...
            [TwoModFreq',TwoRatF1'],...
            [TwoModFreq',TwoRatF2'],...
            [[0.1 100]',[1.6 1.6]']};
    % FIGURE
	CURFIGNO = CURFIGNO + 1;
	FigParam.FigNo = CURFIGNO;
	FigParam.Name = 'ModFreqLimit';
	FigParam.Style = {'none','none','none','none','-'};
	FigParam.Marker = {'o','o','+','+','none'};
	FigParam.YLim = [0,10]; FigParam.XLim = [0.1,100];
    FigParam.Log = 'x';
    fnGenericDrawFigure(FigData,FigParam)
    % PRINT
	%print('-depsc2',[OutPutFigDir 'ModFreqLimit'])
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Modulation amplitude limitations
%
% Originally from 'Data_2002_07_25_RangePlots'
% with the switch set to 'Comparison Plots'.
%  Using data from 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if ModAmpdLimit
	% THz freqs of interest
	F1 = 0.5; F2 = 0.2;
	% Bias voltages, corresponding displacements & multiplot files
	Multiplot = [10 7 9 1 8 2 3 4 6];
	for cK = 1:9
		load(['Data/2002_07_25/SPM_GenericMultiPlot' num2str(Multiplot(cK)) '_Ratio'])
		RatF1(cK) = RegRat(max(find(RegFr<=F1)));
		RatF2(cK) = RegRat(max(find(RegFr<=F2)));
	end
    % DATA
 	ModAmpdVolt = [0.2 0.5 0.8 1 1.5 2 3 4 6];
	ModAmpdDist = 0.36*ModAmpdVolt;
    FigData = {[ModAmpdDist',RatF1'],...
            [ModAmpdDist',RatF2'],...
            [[0 2.5]',[1.6 1.6]']};
    % FIGURE
	CURFIGNO = CURFIGNO + 1;
	FigParam.FigNo = CURFIGNO;
	FigParam.Name = 'ModAmpdLimit';
	FigParam.Style = {'none','none','-'};
	FigParam.Marker = {'o','+','none'};
	FigParam.YLim = [0,4]; FigParam.XLim = [0,2.5];
    FigParam.Log = 'off';
    fnGenericDrawFigure(FigData,FigParam)
    % PRINT
	%print('-depsc2',[OutPutFigDir 'ModAmpdLimit'])
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Time-Domain Confirmation of Liq DTDS
%
% Originally from 'Matlab/Presentation_2002_LiqDTDS.m'
% Liq DTDS ('Liq_DTDS_Hexanes')
% Wave 1 (AC); Wave 2 & Wave 3 (DC)
% (Use the data from 2002.07.25
%  at 10 Hz and 2 VAC.)
% (Export the plot of 2 smoothed waveforms (Fig 20).)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if LiWaveTest
	% 2v p-p, 2002.07.25    
	expfile='F:/Data/2002_07_25/SPM_GenericMultiPlot2_LessBW_Thesis.txt';
	SPM_GenericMultiPlot
    % DATA
    FigData = {[Time{1}'.*1e12,-1*(+WaveSmooth{2}-WaveSmooth{3})/2],...
        [Time{1}'.*1e12,WaveSmooth{1}]};
    % FIGURE
	CURFIGNO = CURFIGNO + 1;
	FigParam.FigNo = CURFIGNO;
	FigParam.Name = 'LiWaveTest';
	FigParam.Style = {'none','-'};
	FigParam.Marker = {'+','none'};
	FigParam.YLim = [-0.015,0.015]; FigParam.XLim = [8,20];
    FigParam.Log = 'off';
    FigParam.LegPos = 1;
    fnGenericDrawFigure(FigData,FigParam)
    % PRINT
	%print('-depsc2',[OutPutFigDir 'LiWaveTest'])
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%
%
% Plots of n, k for:
%  Mix1 (Di00) 			2002.05.03.Dioxane
%  Mix2 (Di02) 			2002.06.25.Protein
%  Mix3 (Di00+SC08) 	2002.05.03.Dioxane
%  Mix4 (Di02+SC10) 	2002.06.25.Protein
% Originally from Matlab/Presentation_2002_MEMS
%  although the mix2 and mix3 are now swapped.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if UncerCompar
    ExpFiles = {'F:/Data/2002_05_03/SPM_GenericMultiPlot_Di00_All_ThesisLi.txt',...
            'F:/Data/2002_06_25_Protein/SPM_GenericMultiPlot_S1_ThesisLi.txt',...
            'F:/Data/2002_05_04/SPM_GenericMultiPlot_SU40_Good_ThesisLi.txt',...
            'F:/Data/2002_06_25_Protein/SPM_GenericMultiPlot_S2_ThesisLi.txt'};
    for MixNo = 1:4
        expfile = ExpFiles{MixNo}; fprintf('\n ---- Mix No %d',MixNo)
        
        SPM_GenericMultiPlot
        NumExps = (length(DataFile.Tr)/2);
        FreqMx{MixNo} = ones(NumExps,1)*FreqArg{1}';
        FreqAbsMx{MixNo} = ones(NumExps,1)*FreqAbs{1}';
        NCutAbsMx{MixNo} = NCutAbs{1};
        for cK = 1:NumExps
            % Transmission
            TranAbsMx{MixNo}(cK,:) = TranAbs{cK}';
            TranArgMx{MixNo}(cK,:) = TranArg{cK}';
            % References
            kk = 2*cK;
            RefAbsMx{MixNo}(cK,:) = Abs{kk}';
            RefArgMx{MixNo}(cK,:) = Arg{kk}';
            SamAbsMx{MixNo}(cK,:) = Abs{kk-1}';
        end
        ddiff{MixNo} = DataFile.ds(1) - DataFile.ds(2);
        clear expfile kk cK
    end %LOOP
    % Parameter estimation
    for cK = 1:4
        % Matricies
        RdexMx{cK} = TranArgMx{cK}.*(c0)./(2*pi*FreqMx{cK}.*ddiff{cK}) + 1;
        KappaMx{cK} = -log(TranAbsMx{cK}(:,NCutAbsMx{cK})).*...
            (c0./(2*pi*FreqMx{cK}.*ddiff{cK}));
        AlphMx{cK} = 4*pi*KappaMx{cK}.*FreqMx{cK}/3e8;
        EpPriMx{cK} = (abs(RdexMx{cK})).^2 - (abs(KappaMx{cK})).^2;
        EpPriPriMx{cK}  = 2.*RdexMx{cK}.*KappaMx{cK};
        EpMx{cK} =  abs(EpPriMx{cK} - j*EpPriPriMx{cK});
        % STD
        TranAbsMean{cK} = mean(TranAbsMx{cK})';
        TranAbsSTD{cK} = std(TranAbsMx{cK})';
        TranArgMean{cK} = mean(TranArgMx{cK})';
        TranArgSTD{cK} = std(TranArgMx{cK})';
        RefAbsMean{cK} = mean(RefAbsMx{cK})';
        RefAbsSTD{cK} = std(RefAbsMx{cK})';
        RefArgMean{cK} = mean(RefArgMx{cK})';
        RefArgSTD{cK} = std(RefArgMx{cK})';
        KappaMean{cK} = mean(KappaMx{cK})';
        KappaSTD{cK} = std(KappaMx{cK})';
        RdexMean{cK}= mean(RdexMx{cK})';
        RdexSTD{cK} = std(RdexMx{cK})';
        % Sam
        SamAbsMean{cK} = mean(SamAbsMx{cK})';			
        SamAbsSTD{cK} = std(SamAbsMx{cK})';
        % Calculated uncertainty
        KappaUncer{cK} = sqrt(2)*c0./(2*pi*FreqMx{cK}(1,:)')/ddiff{cK}...
            .*RefAbsSTD{cK}(NCutAbsMx{cK})./RefAbsMean{cK}(NCutAbsMx{cK});
        RdexUncer{cK} = 2*c0./(2*pi*FreqMx{cK}(1,:)')/ddiff{cK}.*RefArgSTD{cK};
    end %LOOP
    % DATA n summary
    FigData = {[FreqMx{2}(1,:)'*1e-12,RdexSTD{2}],...
            [FreqMx{2}(1,:)'*1e-12,RdexUncer{2}]};
    % FIGURE n summary
	CURFIGNO = CURFIGNO + 1;
	FigParam.FigNo = CURFIGNO;
	FigParam.Name = 'UncerCompar_n_Di';
    FigParam.Color = LINECOLOR;
	FigParam.Style = {'none','-'};
	FigParam.Marker = {'s','none'};
	FigParam.YLim = [0,0.12]; FigParam.XLim = [0.3,1.1];
    FigParam.Log = 'off';
    fnGenericDrawFigure(FigData,FigParam)
    % DATA n
    FigData = {[FreqMx{1}(1,:)'*1e-12,RdexSTD{1}],...
            [FreqMx{2}(1,:)'*1e-12,RdexSTD{2}],...
            [FreqMx{3}(1,:)'*1e-12,RdexSTD{3}],...
            [FreqMx{1}(1,:)'*1e-12,RdexUncer{1}],...
            [FreqMx{2}(1,:)'*1e-12,RdexUncer{2}],...
            [FreqMx{3}(1,:)'*1e-12,RdexUncer{3}]};
    % FIGURE n
	CURFIGNO = CURFIGNO + 1;
	FigParam.FigNo = CURFIGNO;
	FigParam.Name = 'UncerCompar_n';
    FigParam.Color = {LINECOLOR{1:3},LINECOLOR{1:3}}
	FigParam.Style = {'none','none','none',...
        '-','--',':'};
	FigParam.Marker = {'o','s','*',...
        'none','none','none'};
	FigParam.YLim = [0,0.12]; FigParam.XLim = [0.3,1.1];
    FigParam.Log = 'off';
    fnGenericDrawFigure(FigData,FigParam)
    % PRINT n
	%print('-depsc2',[OutPutFigDir 'UncerCompar_n'])
    % DATA k
    FigData = {[FreqMx{1}(1,:)'*1e-12,KappaSTD{1}],...
            [FreqMx{2}(1,:)'*1e-12,KappaSTD{2}],...
            [FreqMx{3}(1,:)'*1e-12,KappaSTD{3}],...
            [FreqMx{1}(1,:)'*1e-12,KappaUncer{1}],...
            [FreqMx{2}(1,:)'*1e-12,KappaUncer{2}],...
            [FreqMx{3}(1,:)'*1e-12,KappaUncer{3}]};
    % FIGURE k
	CURFIGNO = CURFIGNO + 1;
	FigParam.FigNo = CURFIGNO;
	FigParam.Name = 'UncerCompar_k';
	FigParam.YLim = [0,0.01]; FigParam.XLim = [0.3,1.1];
    fnGenericDrawFigure(FigData,FigParam)
    % PRINT k
	%print('-depsc2',[OutPutFigDir 'UncerCompar_k'])
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Example of monoscanning.
%
% Originally from 'Data_2002_07_25_RangePlots'
% with the switch set to 'Comparison Plots'.
%  Using data from 
% Multiplot: (1) real_yr, (2) real_ys, (3) ampd, (4) mean
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if MonoScan
    expfile = 'F:/Data/2001_11_04/SPM_GenericMultiPlot_ThesisLi.txt';
    SPM_GenericMultiPlot
    % DATA yr
    FigData = {[Time{1}'*1e12,Wave{1}],...     %real yr
            [Time{4}'*1e12,Wave{4}+Wave{3}]};  %yr
    % FIGURE yr
	CURFIGNO = CURFIGNO + 1;
	FigParam.FigNo = CURFIGNO;
	FigParam.Name = 'MonoScanyr';
	FigParam.Style = {'none','-'};
	FigParam.Marker = {'o','none'};
	FigParam.YLim = [-0.015,0.04]; FigParam.XLim = [0,3.335];
    FigParam.Log = 'off';
    FigParam.LegPos = 1;
    fnGenericDrawFigure(FigData,FigParam)
    % DATA ys
    FigData = {[Time{2}'*1e12,Wave{2}],...        %real ys
            [Time{4}'*1e12,Wave{4}-Wave{3}]};  %ys
    % FIGURE ys
	CURFIGNO = CURFIGNO + 1;
	FigParam.FigNo = CURFIGNO;
	FigParam.Name = 'MonoScanys';
	FigParam.Style = {'none','-'};
	FigParam.Marker = {'o','none'};
	FigParam.YLim = [-0.015,0.04]; FigParam.XLim = [0,3.335];
    FigParam.Log = 'off';
    FigParam.LegPos = 1;
    fnGenericDrawFigure(FigData,FigParam)
    %% PRINT k
	%%print('-depsc2',[OutPutFigDir 'MonoScan'])
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Plot of Equation 'e:li:ThickerLiquidUncertainty'.
%
% Using k value for (i) water and (ii) dioxane.
%  Spectrometer values are same as in the previous section:
%  dps = 0.015, p = 0.655.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if ThickerLiquidUncertainty
    d = logspace(-6,-1);
    k = {0.013,0.478};
    dps = 0.015;
    dk{1} = sqrt(2)*c0./(2*pi*1e12*d).*dps./(exp(-2*pi*1e12*d*k{1}/c0));
    dk{2} = sqrt(2)*c0./(2*pi*1e12*d).*dps./(exp(-2*pi*1e12*d*k{2}/c0));
    
    % DATA
    FigData = {[d',dk{1}']...
            [d',dk{2}']...
            [[1e-4,1e-4]',[1e-4,1e-1]']...
            [[4e-3,4e-3]',[1e-4,1e-2]']};
    % FIGURE k
	CURFIGNO = CURFIGNO + 1;
	FigParam.FigNo = CURFIGNO;
	FigParam.Name = 'ThickerLiquidUncertainty';
	FigParam.Style = {'-','-','-','-'};
	FigParam.Marker = {'o','o','none','none'};
	FigParam.YLim = [1e-4,1e2]; FigParam.XLim = [1e-6,1e-1];
    FigParam.Log = 'on';
    fnGenericDrawFigure(FigData,FigParam)
    % PRINT k
	%print('-depsc2',[OutPutFigDir 'ThickerLiquidUncertainty'])
end