%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% FIGURE GENERATION FOR SPM THESIS (2003), ChPr
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fprintf('\n **** SPM: Thesis 2003, ChPr **** ')
clear, cd ..

% Variables
DO_NOT_CLEAR = 1; c0 = 2.99792e8;
global MYLINEWIDTH MYSUBLINEWIDTH ...
	MYMARKER MYMARKERSIZE MYSUBMARKERSIZE... 
    LINECOLOR...
	MYFONTSIZE MYSUBFONTSIZE...
	CURFIGNO...
	MYXLABELSHIFT MYYLABELSHIFT...
    OUTPUTFIGDIR
OutPutFigDir = [OUTPUTFIGDIR 'ChPr/Figure/'];

% Paragraphs
SolventSpectrum = 0;
Mixes5  = 1;
 % Subparagraphs
 S_s         = 0; MixDi       = 0; MixDiAq     = 0; MixDiPr     = 0;
 Mixes123    = 0; MixDiAqPr   = 1; MixDiAqFree = 0; Mixes345    = 0;
DiAqModel = 0;
DioxRdex  = 0;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% SolventSpectrum
%
% Spectrum of solvent, an- and hydrous.
% Originally from Presentation_2002_CLEO
%  third attempt at the Toluene.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if SolventSpectrum
    ExpFiles = {'F:/Data/2001_11_12/SpecDuvill96_Tol_H_1',...
        'F:/Data/2001_11_12/SpecDuvill96_Tol_1'};
    %File={'H_1','H_2','H_Chy_1','H_Chy_2','1','2','A_Chy_1','A_Chy_2','A_Chy_3'}
    for cK = 1:length(ExpFiles)
        load([ExpFiles{cK} '.mat'])
        F{cK}=fr;
        R{cK}=RdexOut;
        K{cK}=KappaOut;
    end
    % DATA
    FigData = {[fr*1e-12,R{1}'],...
            [fr*1e-12,R{2}']};
    plot(FigData{1}(:,1),FigData{1}(:,2));
    % FIGURE   
    CURFIGNO = CURFIGNO + 1;
	FigParam.FigNo = CURFIGNO;
	FigParam.Name = 'SolventSpectrum';
	FigParam.XShift = MYXLABELSHIFT;
	FigParam.YShift = MYYLABELSHIFT;
	FigParam.LineWidth = MYLINEWIDTH;
	FigParam.FontSize = MYSUBFONTSIZE;
	FigParam.Color = LINECOLOR;
	FigParam.Style = {'-','-'};
	FigParam.Marker = {'o','o'};
    FigParam.MarkerSize = MYMARKERSIZE;
	FigParam.XLim = [0.2,2]; %FigParam.YLim = [1.5,1.6];
    FigPara.LegPos = 2; %Upper Left
	fnGenericDrawFigure(FigData,FigParam)
    legend('AAAAAAAAAAAAAAAAAAAA','BBBBBBBBBBBBBBBBBBBB')
	% PRINT
	print('-depsc2',[OutPutFigDir 'SolventSpectrum'])
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Mixes5
%
% Plots of n, k for:
%  Mix1 (Di00) 			2002.05.03.Dioxane
%  Mix2 (Di02) 			2002.06.25.Protein
%  Mix3 (Di00+SC08) 	2002.05.03.Dioxane
%  Mix4 (Di02+SC10) 	2002.06.25.Protein
%  Mix5 (Di02-SC10) 	2002.06.25.Protein
% Originally from Matlab/Presentation_2002_MEMS
%  although the mix2 and mix3 are now swapped.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if Mixes5
    FigPara.LegPos = 2; %Upper Left
	FigsOn = 0; ErrorBars = 1; PresentationPlots = 1;
	% Expfile must say: Sam,Ref,Sam,Ref,...
	ExpFiles = {'F:/Data/2002_05_03/SPM_GenericMultiPlot_Di00_All_ThesisPr.txt',...
			'F:/Data/2002_06_25_Protein/SPM_GenericMultiPlot_S1_ThesisPr.txt',...
			'F:/Data/2002_05_04/SPM_GenericMultiPlot_SU40_Good_ThesisPr.txt',...
			'F:/Data/2002_06_25_Protein/SPM_GenericMultiPlot_S2_ThesisPr.txt',...
			'F:/Data/2002_06_26_Protein/SPM_GenericMultiPlot_S2_ThesisPr.txt'};
	for MixNo = 1:5
		expfile = ExpFiles{MixNo}; fprintf('\n ---- Mix No %d',MixNo)
		SPM_GenericMultiPlot
		NumExps = (length(DataFile.Tr)/2);
		FreqMx{MixNo} = ones(NumExps,1)*FreqArg{1}';
        FreqAbsMx{MixNo} = ones(NumExps,1)*FreqAbs{1}';
		NCutAbsMx{MixNo} = NCutAbs{1};
		for cK = 1:NumExps
			% Transmission
			TranAbsMx{MixNo}(cK,:) = TranAbs{cK}';
			TranArgMx{MixNo}(cK,:) = TranArg{cK}';
			% References
			kk = 2*cK;
			RefAbsMx{MixNo}(cK,:) = Abs{kk}';
			RefArgMx{MixNo}(cK,:) = Arg{kk}';
			SamAbsMx{MixNo}(cK,:) = Abs{kk-1}';
		end
		ddiff{MixNo} = DataFile.ds(1) - DataFile.ds(2);
		clear expfile kk cK
	end %LOOP
	% Parameter estimation
	for cK = 1:length(ddiff)
		if ~isempty(ddiff{cK})
			% Matricies
			RdexMx{cK} = TranArgMx{cK}.*(c0)./(2*pi*FreqMx{cK}.*ddiff{cK}) + 1;
			KappaMx{cK} = -log(TranAbsMx{cK}(:,NCutAbsMx{cK})).*...
				(c0./(2*pi*FreqMx{cK}.*ddiff{cK}));
			AlphMx{cK} = 4*pi*KappaMx{cK}.*FreqMx{cK}/3e8;
			EpPriMx{cK} = (abs(RdexMx{cK})).^2 - (abs(KappaMx{cK})).^2;
			EpPriPriMx{cK}  = 2.*RdexMx{cK}.*KappaMx{cK};
			EpMx{cK} =  abs(EpPriMx{cK} - j*EpPriPriMx{cK});
			% STD
			TranAbsMean{cK} = mean(TranAbsMx{cK})';
			TranAbsSTD{cK} = std(TranAbsMx{cK})';
			TranArgMean{cK} = mean(TranArgMx{cK})';
			TranArgSTD{cK} = std(TranArgMx{cK})';
			RefAbsMean{cK} = mean(RefAbsMx{cK})';
			RefAbsSTD{cK} = std(RefAbsMx{cK})';
			RefArgMean{cK} = mean(RefArgMx{cK})';
			RefArgSTD{cK} = std(RefArgMx{cK})';
			KappaMean{cK} = mean(KappaMx{cK})';
			KappaSTD{cK} = std(KappaMx{cK})';
			RdexMean{cK}= mean(RdexMx{cK})';
			RdexSTD{cK} = std(RdexMx{cK})';
			% Sam
			SamAbsMean{cK} = mean(SamAbsMx{cK})';			
			SamAbsSTD{cK} = std(SamAbsMx{cK})';
		end
	end
	% Plots
	if FigsOn
		figure(21), clf, figure(22), clf, figure(23), clf, figure(24)
		clf, figure(25), clf, figure(26), clf,	figure(27), clf, figure(28), clf
		LineStyle={'-b','-r','-k','-c','-m','-g','-y',...
				'-b+','-r+','-k+','-c+','-m+','-g+','-y+',...
				'bo','ro','ko','co','mo','go','yo'};
		for cK = 1:length(ddiff)
			if ~isempty(ddiff{cK})
				figure(21), P1{cK} = plot(FreqMx{cK}',RdexMx{cK}',LineStyle{cK}); hold on
				figure(22), P2{cK} = plot(FreqMx{cK}',KappaMx{cK}',LineStyle{cK}); hold on
				if ErrorBars
					figure(23), P3{cK} = errorbar(FreqMx{cK}(1,:),TranAbsMean{cK}(NCutAbsMx{cK}),...
						TranAbsSTD{cK}(NCutAbsMx{cK}),LineStyle{cK}); hold on
					figure(24), P4{cK} = errorbar(FreqMx{cK}(1,:),TranArgMean{cK},...
						TranArgSTD{cK},LineStyle{cK}); hold on
					figure(25), P5{cK} = errorbar(FreqMx{cK}(1,:),RefAbsMean{cK}(NCutAbsMx{cK}),...
						RefAbsSTD{cK}(NCutAbsMx{cK}),LineStyle{cK}); hold on
					figure(26), P6{cK} = errorbar(FreqMx{cK}(1,:),RefArgMean{cK},...
						RefArgSTD{cK},LineStyle{cK}); hold on
					figure(27), P7{cK} = errorbar(FreqMx{cK}(1,:),KappaMean{cK},...
						KappaSTD{cK},LineStyle{cK}); set(P7{cK}(2),'LineWidth',4), hold on
					figure(28), P8{cK} = errorbar(FreqMx{cK}(1,:),RdexMean{cK},...
						RdexSTD{cK},LineStyle{cK}); set(P8{cK}(2),'LineWidth',4), hold on					
				else % No error bars
					figure(23), P3{cK} = plot(FreqMx{cK}(1,:),TranAbsMean{cK}(NCutAbsMx{cK}),LineStyle{cK},...
						FreqMx{cK}(1,:),TranAbsSTD{cK}(NCutAbsMx{cK}),LineStyle{cK+7}); hold on
					figure(24), P4{cK} = plot(FreqMx{cK}(1,:),TranArgMean{cK},LineStyle{cK},...
						FreqMx{cK}(1,:),TranArgSTD{cK},LineStyle{cK+7}); hold on
					figure(25), P5{cK} = plot(FreqMx{cK}(1,:),RefAbsMean{cK}(NCutAbsMx{cK}),LineStyle{cK},...
						FreqMx{cK}(1,:),RefAbsSTD{cK}(NCutAbsMx{cK}),LineStyle{cK+7}); hold on
					figure(26), P6{cK} = plot(FreqMx{cK}(1,:),RefArgMean{cK},LineStyle{cK},...
						FreqMx{cK}(1,:),RefArgSTD{cK},LineStyle{cK+7}); hold on
					figure(27), P7{cK} = plot(FreqMx{cK}(1,:),KappaMean{cK},LineStyle{cK},...
						FreqMx{cK}(1,:),KappaSTD{cK},LineStyle{cK+7},'LineWidth',4); hold on
					figure(28), P8{cK} = plot(FreqMx{cK}(1,:),RdexMean{cK},LineStyle{cK},...
						FreqMx{cK}(1,:),RdexSTD{cK},LineStyle{cK+7},'LineWidth',4); hold on
				end
			end	
		end
		figure(21), set(gcf,'Name','n'), set(gca,'FontSize',MyFontSize)
		legend([P1{1}(1),P1{2}(1),P1{3}(1),P1{4}(1),P1{5}(1)],'d','d+w','d+sc','d+sc+fw','d+fw')
		xlabel('Freq (Hz)'), ylabel('n')
		title('DioxMixes from 05.03, .04, & .13')
		figure(22), set(gcf,'Name','k'), set(gca,'FontSize',MyFontSize)
		legend([P2{1}(1),P2{2}(1),P2{3}(1),P2{4}(1),P1{5}(1)],'d','d+w','d+sc','d+sc+w','d+fw')
		xlabel('Freq (Hz)'), ylabel('\kappa')
		title('DioxMixes from 05.03, .04, & .13')
		figure(23), set(gcf,'Name','\rho')
		figure(24), set(gcf,'Name','\phi')
		figure(25), set(gcf,'Name','\rho_R')
		figure(26), set(gcf,'Name','\phi_R')
		figure(27), set(gcf,'Name','k')
		figure(28), set(gcf,'Name','n')
	end
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	% Presentation plots (Thesis)
	if PresentationPlots
        PrLineStyle = {'-o','-o','-o','-o','-o'};
        
		% S_s
        if S_s
        NCutOn = 0;
		figure(31), clf, set(gcf,'Name','S_s')
        if NCutOn
        S_s_SNR = SamAbsMean{1}(NCutAbsMx{1})./SamAbsSTD{1}(NCutAbsMx{1});
		P31{1} = semilogy(FreqMx{1}(1,:)*1e-12,SamAbsMean{1}(NCutAbsMx{1}),PrLineStyle{1},...
			FreqMx{1}(1,:)*1e-12,SamAbsSTD{1}(NCutAbsMx{1}),PrLineStyle{2},...
            FreqMx{1}(1,:)*1e-12,S_s_SNR,PrLineStyle{3});
        else
        S_s_SNR = SamAbsMean{1}./SamAbsSTD{1};
		P31{1} = semilogy(FreqAbsMx{1}(1,:)*1e-12,SamAbsMean{1},PrLineStyle{1},...
			FreqAbsMx{1}(1,:)*1e-12,SamAbsSTD{1},PrLineStyle{2},...
            FreqAbsMx{1}(1,:)*1e-12,S_s_SNR,PrLineStyle{3});
        hold on
        P31{2} = semilogy([1.1,1.1],[1e-4,1e4],PrLineStyle{4},...
            [0.2,0.2],[1e-4,1e4],PrLineStyle{4});
        end
		set(P31{1},'LineWidth',1)
		set(P31{2},'LineWidth',1)
		set(gca,'FontSize',MYSUBFONTSIZE), xlabel('XX'), ylabel('YY')
		xlim([0 2]), ylim([1e-4 1e5])
		set(P31{1}(1),'MarkerSize',MYMARKERSIZE,'Color',LINECOLOR{1})
        set(P31{1}(2),'MarkerSize',MYMARKERSIZE,'Color',LINECOLOR{2})
        set(P31{1}(3),'MarkerSize',MYMARKERSIZE,'Color',LINECOLOR{3})
        set(P31{2},'MarkerSize',MYMARKERSIZE,'Color',LINECOLOR{4})
		legend('AAAAAAAAAAAAAAAAAAAAAAAAA','UNCERTAINTY','SNR','GOOD',2)
        print('-depsc2',[OutPutFigDir 'S_s'])
        end

        % dioxane
        if MixDi
		figure(32), clf, set(gcf,'Name','MixDi')
	    P32 = errorbar(FreqMx{1}(1,:)*1e-12,KappaMean{1},...
            KappaSTD{1},PrLineStyle{1});
        set(P32,'LineWidth',1)
		set(gca,'FontSize',MYSUBFONTSIZE), xlabel('XX'), ylabel('YY')
		ylim([0 0.04]), xlim([0.195 1.1062])
		set(P32,'MarkerSize',MYMARKERSIZE,'Color',LINECOLOR{1})	
		legend([P32(2)],'AAAAAAAAAAAAAAAAAAAAAAAAA',2)
        print('-depsc2',[OutPutFigDir 'MixDi'])
        end
        
        % dioxane and water
        if MixDiAq
		figure(33), clf, set(gcf,'Name','MixDiAq')
	    P33{1} = errorbar(FreqMx{1}(1,:)*1e-12,KappaMean{1},...
            KappaSTD{1},PrLineStyle{1});
		set(P33{1},'LineWidth',1,'MarkerSize',2,'Color',LINECOLOR{1})
        hold on
	    P33{2} = errorbar(FreqMx{2}(1,:)*1e-12,KappaMean{2},...
            KappaSTD{2},PrLineStyle{2});
		set(P33{2},'LineWidth',1,'MarkerSize',MYMARKERSIZE,'Color',LINECOLOR{2})
		set(gca,'FontSize',MYSUBFONTSIZE), xlabel('XX'), ylabel('YY')
		ylim([0 0.04]), xlim([0.195 1.1062])
		legend([P33{1}(2),P33{2}(2)],'AAAAAAAAAAAAAAAAAAAAAAAAA','MixDiAq',2)
        print('-depsc2',[OutPutFigDir 'MixDiAq'])
        end

        % dioxane and protein
        if MixDiPr
        figure(34), clf, set(gcf,'Name','MixDiPr')
	    P34{1} = errorbar(FreqMx{1}(1,:)*1e-12,KappaMean{1},...
            KappaSTD{1},PrLineStyle{1});
		set(P34{1},'LineWidth',1,'MarkerSize',MYMARKERSIZE,'Color',LINECOLOR{1})
        hold on
	    P34{3} = errorbar(FreqMx{3}(1,:)*1e-12,KappaMean{3},...
            KappaSTD{3},PrLineStyle{3});
		set(P34{3},'LineWidth',1,'MarkerSize',MYMARKERSIZE,'Color',LINECOLOR{3})
		set(gca,'FontSize',MYSUBFONTSIZE), xlabel('XX'), ylabel('YY')
		ylim([0 0.04]), xlim([0.195 1.1062])
		legend([P34{1}(2),P34{3}(2)],'AAAAAAAAAAAAAAAAAAAAAAAAA','MixDiPr',2)
        print('-depsc2',[OutPutFigDir 'MixDiPr'])
        end

        % Mixes123
        if Mixes123
		figure(35), clf, set(gcf,'Name','Mixes123')
	    for cK = 1:3, P35{cK} = plot(FreqMx{cK}(1,:)*1e-12,...
			KappaMean{cK},PrLineStyle{cK}); hold on,...
			set(P35{cK},'LineWidth',1,'MarkerSize',MYMARKERSIZE,...
            'Color',LINECOLOR{cK}), end
		set(gca,'FontSize',MYSUBFONTSIZE), xlabel('XX'), ylabel('YY')
		ylim([0 0.04]), xlim([0.195 1.1062])
		legend('AAAAAAAAAAAAAAAAAAAAAAAAA','MixDiAq','MixDiPr',2)
        print('-depsc2',[OutPutFigDir 'Mixes123'])
        end
        
		% dioxane and water and SC
        if MixDiAqPr
		figure(36), clf, set(gcf,'Name','MixDiAqPr')
	    P36{2} = errorbar(FreqMx{2}(1,:)*1e-12,KappaMean{2},...
            KappaSTD{2},PrLineStyle{2});
		set(P36{2},'LineWidth',1,'MarkerSize',MYMARKERSIZE,'Color',LINECOLOR{2})
        hold on
		P36{3} = errorbar(FreqMx{3}(1,:)*1e-12,KappaMean{3},...
            KappaSTD{3},PrLineStyle{3});
		set(P36{3},'LineWidth',1,'MarkerSize',MYMARKERSIZE,'Color',LINECOLOR{3})
        P36{4} = errorbar(FreqMx{4}(1,:)*1e-12,KappaMean{4},...
            KappaSTD{4},PrLineStyle{4});
		set(P36{4},'LineWidth',1,'MarkerSize',MYMARKERSIZE,'Color',LINECOLOR{4})
        set(gca,'FontSize',MYSUBFONTSIZE), xlabel('XX'), ylabel('YY')
		ylim([0 0.04]), xlim([0.195 1.1062])
		legend([P36{2}(2),P36{3}(2),P36{4}(2)],'AAAAAAAAAAAAAAAAAAAAAAAAA','MixDiPr','MixDiAqPr',2)
        print('-depsc2',[OutPutFigDir 'MixDiAqPr'])
        end
        
		% dioxane and free water
        if MixDiAqFree
		figure(37), clf, set(gcf,'Name','MixDiAqFree')
		P37{4} = errorbar(FreqMx{4}(1,:)*1e-12,KappaMean{4},...
            KappaSTD{4},PrLineStyle{4});
		set(P37{4},'LineWidth',1,'MarkerSize',MYMARKERSIZE,'Color',LINECOLOR{4})
        hold on
        P37{5} = errorbar(FreqMx{5}(1,:)*1e-12,KappaMean{5},...
            KappaSTD{5},PrLineStyle{5});
		set(P37{5},'LineWidth',1,'MarkerSize',MYMARKERSIZE,'Color',LINECOLOR{5})
        set(gca,'FontSize',MYSUBFONTSIZE), xlabel('XX'), ylabel('YY')
		ylim([0 0.04]), xlim([0.195 1.1062])
		legend([P37{4}(2),P37{5}(2)],'AAAAAAAAAAAAAAAAAAAAAAAAA','MixDiAqFree',2)
        print('-depsc2',[OutPutFigDir 'MixDiAqFree'])
        end
        
		% Mixes345
        if Mixes345
		figure(38), clf, set(gcf,'Name','Mixes345')
		for kk = 1:3, cK = kk+2; P41{cK} = plot(FreqMx{cK}(1,:)*...
				1e-12,KappaMean{cK},PrLineStyle{cK}); hold on,...
			set(P41{cK},'LineWidth',1,'MarkerSize',MYMARKERSIZE,...
            'Color',LINECOLOR{cK}), end
		set(gca,'FontSize',MYSUBFONTSIZE), xlabel('XX'), ylabel('YY')
		ylim([0 0.04]), xlim([0.195 1.1062])
		legend('MixDiPr','MixDiAqPr','MixDiAqFree',2)
        print('-depsc2',[OutPutFigDir 'Mixes345'])
        end
	end
end	


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% DiAqModel
%
% Water Debye spectrum from ronne97 mixed with dioxane.
% Originally from Matlab/Presentation_2002_MEMS
%  although the mix2 and mix3 are now swapped.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if (Mixes5 & DiAqModel)
	% FIRST run Mixes5 to get plot of dioxane.
	% Ronne97 Debye Coefs at 19.15 deg. C
	e_inf = 3.3; e_s = 80.528; e_1 = 5.2;
	t_d = 8.5e-12; t_2 = 170e-15;
	% Compare to dielco of Mix1
	ronne97_omega = 2*pi*FreqMx{1}(1,:);
	ERonne97 = ( e_inf + (e_s+e_1)./(1+j*ronne97_omega*t_d) + ...
		(e_1-e_inf)./(1+j*ronne97_omega*t_2) )';
	% Plot *k* of Mix1, Ronne97 and perfect mix 
	%  (vol % from 2 uL water in 1 mL dioxane)
	vw = 0.0020; vd = 0.9980;
	Ronne97k = imag(sqrt(ERonne97));
	RonneMixk = vw*Ronne97k + vd*KappaMean{1};
	%  (vol % from 2 uL water in 1 mL dioxane)
	vw2 = 0.015; vd2 = 0.9850;
	RonneMixk2 = vw2*Ronne97k + vd2*KappaMean{1};
	F = (FreqMx{1}(1,:)*1e-12)';
	figure(69), clf
	P69 = plot(...
		F,KappaMean{1},PrLineStyle{1},...
		F,KappaMean{2},PrLineStyle{2},...
		F,RonneMixk,PrLineStyle{3},...
		F,RonneMixk2,PrLineStyle{4});
	set(P69,'LineWidth',1)
	set(P69(1),'MarkerSize',MYMARKERSIZE,'Color',LINECOLOR{1})
	set(P69(2),'MarkerSize',MYMARKERSIZE,'Color',LINECOLOR{2})
	set(P69(3),'MarkerSize',MYMARKERSIZE,'Color',LINECOLOR{3})
	set(P69(4),'MarkerSize',MYMARKERSIZE,'Color',LINECOLOR{4})
	set(gca,'FontSize',MYSUBFONTSIZE), set(gcf,'Name','IdealMix')
	legend('AAAAAAAAAAAAAAAAAAAAAAAAA','BBBBBBBBBB','CCCCCCCCCC','DDDDDDDDDD',2)
	ylim([0 0.045]), xlim([0.195 1.1062]), xlabel('XX'), ylabel('YY')
    print('-depsc2',[OutPutFigDir 'IdealMix'])
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% DioxRdex
%
% Refractive index of dioxane
%  (just pulled out of above, with BW to 2 THz
%  and padding).
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if DioxRdex
	% DATA
    expfile = 'F:/Data/2002_05_03/SPM_GenericMultiPlot_Di00_All_2THz.txt';
  	SPM_GenericMultiPlot
	NumExps = (length(DataFile.Tr)/2);
    MixNo = 1;
	FreqMx{MixNo} = ones(NumExps,1)*FreqArg{1}';
    FreqAbsMx{MixNo} = ones(NumExps,1)*FreqAbs{1}';
	NCutAbsMx{MixNo} = NCutAbs{1};
	for cK = 1:NumExps
		% Transmission
		TranAbsMx{MixNo}(cK,:) = TranAbs{cK}';
		TranArgMx{MixNo}(cK,:) = TranArg{cK}';
		% References
		kk = 2*cK;
		RefAbsMx{MixNo}(cK,:) = Abs{kk}';
		RefArgMx{MixNo}(cK,:) = Arg{kk}';
		SamAbsMx{MixNo}(cK,:) = Abs{kk-1}';
	end
	ddiff{MixNo} = DataFile.ds(1) - DataFile.ds(2);
	cK = 1;
    % Matricies
    RdexMx{cK} = TranArgMx{cK}.*(c0)./(2*pi*FreqMx{cK}.*ddiff{cK}) + 1;
    KappaMx{cK} = -log(TranAbsMx{cK}(:,NCutAbsMx{cK})).*...
        (c0./(2*pi*FreqMx{cK}.*ddiff{cK}));
    AlphMx{cK} = 4*pi*KappaMx{cK}.*FreqMx{cK}/3e8;
    EpPriMx{cK} = (abs(RdexMx{cK})).^2 - (abs(KappaMx{cK})).^2;
    EpPriPriMx{cK}  = 2.*RdexMx{cK}.*KappaMx{cK};
    EpMx{cK} =  abs(EpPriMx{cK} - j*EpPriPriMx{cK});
    % STD
    TranAbsMean{cK} = mean(TranAbsMx{cK})';
    TranAbsSTD{cK} = std(TranAbsMx{cK})';
    TranArgMean{cK} = mean(TranArgMx{cK})';
    TranArgSTD{cK} = std(TranArgMx{cK})';
    RefAbsMean{cK} = mean(RefAbsMx{cK})';
    RefAbsSTD{cK} = std(RefAbsMx{cK})';
    RefArgMean{cK} = mean(RefArgMx{cK})';
    RefArgSTD{cK} = std(RefArgMx{cK})';
    KappaMean{cK} = mean(KappaMx{cK})';
    KappaSTD{cK} = std(KappaMx{cK})';
    RdexMean{cK}= mean(RdexMx{cK})';
    RdexSTD{cK} = std(RdexMx{cK})';
    % Sam
    SamAbsMean{cK} = mean(SamAbsMx{cK})';			
    SamAbsSTD{cK} = std(SamAbsMx{cK})';
    % PLOT
    figure(21), clf, P1{cK} = plot(FreqMx{cK}',RdexMx{cK}',LineStyle{cK});
    figure(22), clf, P2{cK} = plot(FreqMx{cK}',KappaMx{cK}',LineStyle{cK});
end