
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% FIGURE GENERATION FOR SPM THESIS (2003), ChSr
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
fprintf('\n **** SPM: Thesis 2003, ChSr **** ')
clear, cd ..

% Variables
DO_NOT_CLEAR = 1; c0 = 2.99792e8;
global MYLINEWIDTH MYSUBLINEWIDTH ...
	MYMARKER MYMARKERSIZE MYSUBMARKERSIZE... 
    LINECOLOR MYLINESTYLE...
	MYFONTSIZE MYSUBFONTSIZE...
	CURFIGNO...
	MYXLABELSHIFT MYYLABELSHIFT...
    OUTPUTFIGDIR
%OutPutFigDir = [OUTPUTFIGDIR 'ChSr/Figure/'];
OutPutFigDir = ['F:\Presentations 2003\2003_12_10 SPIE MEMS\Development Versions\Figure\'];

% Defaults
FigParam.XShift = MYXLABELSHIFT;
FigParam.YShift = MYYLABELSHIFT;
FigParam.LineWidth = MYLINEWIDTH;
FigParam.FontSize = MYFONTSIZE;
FigParam.Color = LINECOLOR;
FigParam.MarkerSize = MYMARKERSIZE;
FigParam.XShift = MYXLABELSHIFT;
FigParam.YShift = MYYLABELSHIFT;
FigParam.LineWidth = MYSUBLINEWIDTH;
FigParam.FontSize = MYSUBFONTSIZE;
FigParam.Color = {[0.72,0,0],[0,0.75,0.16]};
FigParam.Style = {':','-'};
FigParam.Marker = {'none','o'};

% Sections:
Four_Figures = 1;
    Fig_Waves = 1;
    Fig_Energy = 1;
    Fig_TotalEnergy = 1;
    Fig_Spectra = 1;
Calculations = 0;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Four_Figures
%
% simulated waveforms.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if Four_Figures
ts = 66.67e-15; %seconds
tau = 5e-12; %seconds
N = 2^14;
SD_B = 1; %standard deviation of probe beam
E_T_peak = 10; %peak of THz pulse

n = [0:N-1];
t = n*ts;
n_delay = 2^8;
t_delay = n_delay*ts;
E_T_pre = 2.*(t-t_delay)./(tau^2).*exp(-(t-t_delay).^2./tau^2); %for PCA
E_T = E_T_pre.*E_T_peak./(max(E_T_pre));
E_T(1:n_delay) = 0;

randn('state',sum(100*clock));
N_B = SD_B.*randn(1,N); %zero mean gaussian white noise, SD = SD_B

Dynamic_Range = max(E_T) / max(N_B)
T = (N-1)*ts

if Fig_Waves
% DATA Waves
FigData = {[(t./tau)',N_B'],...
			[(t./tau)',E_T']};
% FIGURE   
CURFIGNO = CURFIGNO + 1;
FigParam.FigNo = CURFIGNO;
FigParam.Name = 'Waves';
FigParam.XShift = MYXLABELSHIFT;
FigParam.YShift = MYYLABELSHIFT;
FigParam.LineWidth = MYSUBLINEWIDTH;
FigParam.FontSize = MYSUBFONTSIZE;
FigParam.Style = {':','-'};
FigParam.Marker = {'none','o'};
FigParam.XLim = [0,25]; FigParam.YLim = [-5,12];
% FigParam.LegPos = 1;
fnGenericDrawFigure(FigData,FigParam)
% %%print
%%print('-depsc2',fullfile(OutPutFigDir,'WavesTEMP.eps'))
end

if Fig_Energy
% DATA Energy
FigData = {[(t./tau)',(N_B.^2)'],...
			[(t./tau)',(E_T.^2)']};
% FIGURE   
CURFIGNO = CURFIGNO + 1;
FigParam.FigNo = CURFIGNO;
FigParam.Name = 'Energy';
FigParam.XShift = -30;
FigParam.Log = 'y';
FigParam.XLim = [0,25]; FigParam.YLim = [1e-200,1e10];
FigParam.LegPos = 3;
fnGenericDrawFigure(FigData,FigParam)
% %%print
%%print('-depsc2',[OutPutFigDir 'Energy'])
end

if Fig_TotalEnergy
% DATA TotalEnergy
E_T_tot = cumsum(E_T.^2);
N_B_tot = cumsum(N_B.^2);
FigData = {[(t./tau)',(N_B_tot.^2.*1e-6)'],...
			[(t./tau)',(E_T_tot.^2.*1e-6)']};
% FIGURE   
CURFIGNO = CURFIGNO + 1;
FigParam.FigNo = CURFIGNO;
FigParam.Name = 'TotalEnergy';
FigParam.XShift = MYXLABELSHIFT;
FigParam.Log = 'off';
FigParam.XLim = [0,90]; FigParam.YLim = [0,70];
FigParam.LegPos = 0;
fnGenericDrawFigure(FigData,FigParam)
% %%print
%%print('-depsc2',[OutPutFigDir 'TotalEnergy'])
end

if Fig_Spectra
% DATA Spectra
E_T_k = fftshift(E_T);
N_B_k = fftshift(N_B);
f = [-N/2:N/2-1]./(N-1); %units of fs
f_rang = 1:N;
FigData = {[f(f_rang)',(abs(N_B_k(f_rang)).^2)'],...
			[f(f_rang)',(abs(E_T_k(f_rang)).^2)']};
% FIGURE   
CURFIGNO = CURFIGNO + 1;
FigParam.FigNo = CURFIGNO;
FigParam.Name = 'Spectra';
FigParam.XShift = MYXLABELSHIFT;
FigParam.Log = 'off';
FigParam.XLim = [0,0.10]; FigParam.YLim = [-5,100];
FigParam.LegPos = 1;
fnGenericDrawFigure(FigData,FigParam)
% %%print
%%print('-depsc2',[OutPutFigDir 'Spectra'])
end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Calculations
%
% for a \Delta f.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if Calculations
    SD_B = 1; %standard deviation of probe beam
    E_T_peak = 1e6; %peak of THz pulse
    f_1 = 0.18e12; %1e12*[0.1:0.001:1]'; %0.5e12; %freq of interest in Hz
    tau = 5e-12; %5e-12; %pulse durn in s
    ts = 66.67e-15; %sample rate
    M_f_1 = 0.01; %abs line strength (ratio)

    T_max = ts.*M_f_1.*(E_T_peak./SD_B).^2.*(2.*pi.*f_1.*tau).^2/2.*...
        exp(-(2.*pi.*f_1.*tau).^2./2); %from spectrum of a PCA & white noise in FFT
    delf_min = 1./T_max
    figure(99), subplot(311), semilogy(f_1*1e-12,T_max)
    figure(99), subplot(312), semilogy(f_1*1e-12,delf_min), ylim([1e6 1e10])
    E_T = E_T_peak.*2.*pi.*f_1.*tau/sqrt(2).*exp(-(2.*pi.*f_1.*tau./2).^2);
    figure(99), subplot(313), plot(f_1*1e-12,E_T)
 
end