%SPECDTDSMAIN is for running Sam's algorithm.
%
%  This script reads in all experimental data from a carefully-
%  formatted text file, which must in turm hold all experimental
%  parameters and the filenames of the data files.  For a description
%  of the input text file requirements, see the SpecDTDSREADME.txt.
%
% Sam Mickan Aug 2001

% Setup and get to My Documents
fprintf('\n **** SpecDTDSMain **** \n'), cd ../../, clear all

% Load up parameters for this extraction
expfile='/matlab/DTDS_New/SpecDTDSParylene_KSL.txt';
[waveform,param,fr]=SpecDTDSLoadFilefn(expfile);

% Measured transmission coefficient at freqs fr()
[Texper,Spectra] = SpecDTDSTexperfn(fr,waveform,param);
    
% Loop thru diffnt freqs
for cK=1:length(fr), fprintf('[%d]  ',cK)

    % Scalar error min search (accurate to about 3 sf)
    WhichXtic='Rdex'; Xtic2=-1*imag(param.n2);
    TexpercK=struct('Abs',Texper.Abs(cK),'Arg',Texper.Arg(cK));
    [Rdex,FVAL,EXFLAG,OUTPUT] = fminbnd(@SpecDTDSDelfn,1,10,...
        optimset('TolX',0.000001),...
        WhichXtic,Xtic2,fr(cK),Spectra.F,TexpercK,param);
    WhichXtic='Kappa'; Xtic2=Rdex;
    [Kappa,FVAL,EXFLAG,OUTPUT] = fminbnd(@SpecDTDSDelfn,0,10,...
        optimset('TolX',0.000001),...
        WhichXtic,Xtic2,fr(cK),Spectra.F,TexpercK,param);
    
    OUTPUT.iterations;
    
    % Record characteristics
    RdexOut(cK)=Rdex; KappaOut(cK)=Kappa;
    AlphaOut(cK)=4*pi*fr(cK)*Kappa/param.c0;
   
end %for cK

% Plot results: Rdex, Kappa
if 1==0
    titl=expfile; titl(find(titl=='_'))='-';
    figure(1), clf, plot(fr,RdexOut,'-+',fr,KappaOut,'-o'),
    grid, title(titl), legend('Rdex','Kappa')
end %if1==

% Diagnostics
if 1==1

    % Exper, Model
    for cK=1:length(fr), TmodelOut = SpecDTDSTmodelfn(RdexOut(cK),...
            'Rdex',KappaOut(cK),fr(cK),Spectra.F,param);
        TmodelOutAbs(cK)=TmodelOut.Abs;
        TmodelOutArg(cK)=TmodelOut.Arg; end %for cK=1:length(fr)
    figure(2), clf, titl=expfile; titl(find(titl=='_'))='-';
    subplot(211), plot(fr,Texper.Abs,'-+',fr,TmodelOutAbs','-o'), grid, ...
        ylabel('ABS (a.u.)'), legend('T_{exper}','T_{model}'), title(titl)
    subplot(212), plot(fr,Texper.Arg'*180/pi,'-+',fr,TmodelOutArg'*...
        180/pi,'-o'), grid, xlabel('Freq'), ylabel('ARG (deg)'), ...
        legend('T_{exper}','T_{model}')
    
    % Rdex, Kappa
    h=figure(3); plot(fr,RdexOut,'+-'), grid, set(h,'PaperPosition',[0.1 0.2 6 4]),...
        title(['DTDS - Rdex (' titl ')']), xlabel('F (Hz)'), ylabel('Refractive Index')
    print('-depsc','MyPictures/DTDS_Rdex')
    h=figure(4); plot(fr,KappaOut,'+-'), grid, set(h,'PaperPosition',[0.1 0.2 6 4]),...
        title(['DTDS - Kappa (' titl ')']), xlabel('F (Hz)'), ylabel('\kappa')
    print('-depsc','MyPictures/DTDS_Kappa')
    
    % Waveforms (to cut off freq)
    NcutLow=max(find(Spectra.F<=fr(1)));
    NcutHi=min(find(Spectra.F>=fr(end)));
    Ncut=[NcutLow:NcutHi];    
    figure(5), clf
    subplot(311), plotyy(waveform.time,real(waveform.yr),...
        waveform.time,real(waveform.yd)), title('<-- Ref, Dif -->'), grid
    subplot(312), plotyy(Spectra.F(Ncut),abs(Spectra.Sr(Ncut)),...
        Spectra.F(Ncut),abs(Spectra.Sd(Ncut))), ylabel('ABS'), grid
    subplot(313), plotyy(Spectra.F(Ncut),unwrap(angle(Spectra.Sr(Ncut)))*...
        180/pi,Spectra.F(Ncut),unwrap(angle(Spectra.Sd(Ncut)))*180/pi),...
        ylabel('ARG (deg)'), grid
    
end %1==

% Memory management
    