	function [Texper,Spectra] = SpecDTDSTexperfn(fr,waveform,param)

%SPECDTDSEXPERFN Measured (complex) transmission
%  spectrum at a given  frequency, fr.
%
%  Loads two (complex) vectors, reference and sample, wrt position in 
%  microns, then linearly interpolates a transmission coefficient for
%  the SINGLE frequency(s) defined by fr.  The FFT is padded to length N.
%
%  Input1: reference freq (Hz)
%  Input2: reference waveform vector (au)
%  Input3: sample waveform vector (au)
%  Input4: exp params
%  Input5: should i do plots?
%
%  Sam Mickan August 2001

%Window
%****TBD****

% Spectra
Sr=fft(waveform.yr,param.N);
Sd=fft(waveform.yd,param.N);
if 1==1, Tran=(Sd./Sr); fprintf('T_{exper} NOT using cplx conj.\n'), else
    Tran=conj(Sd./Sr); fprintf('T_{exper} DOES use cplx conj.\n'), end %if 1==

% The unwrap step is very important in providing the correct phase value
TranAbs=abs(Tran); TranArg=unwrap(angle(Tran));

% Frequency vector
F=[0:(param.N-1)]'/(param.dt*(param.N-1));
Nny=[1:floor(param.N/2)];

% Loop thru diffnt freqs
for cK=1:length(fr)

    % Find discrete frequency values on both sides of fr
    val1=max(find(F<=fr(cK))); val2=min(find(F>=fr(cK)));
    
    % Transmission at specific frequency from linear approximation of slope
    %  around point fr
    if val1==val2, 
        TranAbsLoc(cK)=TranAbs(val1);
        TranArgLoc(cK)=TranArg(val1); 
    else
        aAbs=(TranAbs(val2)-TranAbs(val1))/(F(val2)-F(val1));
        bAbs=TranAbs(val1)-aAbs*F(val1);
        TranAbsLoc(cK)=aAbs.*fr(cK)+bAbs;
        aArg=(TranArg(val2)-TranArg(val1))/(F(val2)-F(val1));
        bArg=TranArg(val1)-aArg*F(val1);
        TranArgLoc(cK)=aArg.*fr(cK)+bArg; end %if val1==val2

end %for cK

Texper=struct('Abs',TranAbsLoc',...
    'Arg',TranArgLoc');
Spectra=struct('F',F,'Sr',Sr,'Sd',Sd);
    
% Plots
if 1==0
    figure(3), clf
    subplot(221), plotyy(waveform.time,real(waveform.yr),waveform.time,real(waveform.yd)), title('<-- yr, ys -->'), grid
    subplot(222), plotyy(F(Nny),abs(Sr(Nny)),F(Nny),abs(Sd(Nny))), ...
        title('<-- Sr, Ss -->'), grid
    subplot(223), plotyy(F(Nny),TranAbs(Nny),F(Nny),...
        TranArg(Nny)*180/pi),title('<-- T_{exp}Abs, T_{exp}Arg (deg) -->'), grid
    %fprintf('Nyquist freq is %d\n',F(max(Nny)))
end %if1==

% Diagnostics
if 1==0
    figure(4), clf
    subplot(211), plot(F,abs(Tran)), grid
    ylabel('abs(Tran)')
    subplot(212), plot(F,(angle(Tran))), grid
    ylabel('(arg(Tran))')
    h=figure, set(h,'Name','Duv99'), subplot(211), plot(F,abs(Sr),F,abs(Ss),...
        F,abs(Tran)), legend('Sr','Ss','T'), subplot(212), plot(F,unwrap(angle(Sr)),...
        F,unwrap(angle(Ss)),F,unwrap(angle(Tran))), ylabel('rad')
end %if 1==